"use strict";
const axios_1 = require("axios");
const mqtt_topping_1 = require("mqtt-topping");
const logger_1 = require("@artcom/logger");
function delay(time) {
    return new Promise(resolve => setTimeout(resolve, time));
}
function createClientId(serviceId, device) {
    const uuid = Math.random().toString(16).substr(2, 8);
    return `${serviceId}-${device}-${uuid}`;
}
module.exports = async function init(url, serviceId, { timeout = 2000, retryDelay = 10000 } = {}) {
    const logger = logger_1.createLogger();
    async function query() {
        logger.info("Querying bootstrap data", { url });
        try {
            const response = await axios_1.default.get(url, { timeout });
            return response.data;
        }
        catch (error) {
            logger.error(`Query failed. Retrying in ${retryDelay}ms...`, { error: error.message });
            await delay(retryDelay);
            return await query();
        }
    }
    const bootstrapData = await query();
    logger.info("Bootstrap data received", { ...bootstrapData });
    const { device, tcpBrokerUri, httpBrokerUri, configServerUri } = bootstrapData;
    const clientId = createClientId(serviceId, device);
    logger.info("Connecting to Broker", { tcpBrokerUri, httpBrokerUri, clientId });
    const mqttClient = mqtt_topping_1.default.connect(tcpBrokerUri, httpBrokerUri, { clientId });
    mqttClient.on("connect", () => { logger.info("Connected to Broker"); });
    mqttClient.on("close", () => { logger.error("Disconnected from Broker"); });
    mqttClient.on("error", () => { logger.error("Error Connecting to Broker"); });
    async function queryConfig(configPath, version = "master") {
        return axios_1.default(`${configServerUri}/${version}/${configPath}`).then(({ data }) => data);
    }
    return { logger, mqttClient, queryConfig, data: bootstrapData };
};
//# sourceMappingURL=main.js.map